@@ -13,8 +13,16 @@ from xync_client.Gate.etype import ad
 
 class ExClient(BaseExClient):
     logo_pre_url = "www.gate.io"
-
     _data: dict = {}
+    coin_scales = {
+        "USDT": 2,
+        "BTC": 8,
+        "ETH": 8,
+        "DOGE": 8,
+        "TON": 8,
+        "NOT": 8,
+        "USDC": 2,
+    }
 
     # Данные для р2р из html Gate.io
     @property
@@ -44,7 +52,7 @@ class ExClient(BaseExClient):
     # 22: Списки поддерживаемых платежек по каждой валюте
     async def cur_pms_map(self) -> MapOfIdsList:
         data = self.data
-        return data["fait_payment_settings"]
+        return {d["fiat"]: [p["pay_type"] for p in d["pay_info"]] for d in data["fait_payment_settings"]}
 
     async def pairs(self) -> MapOfIdsList:
         coins = (await self.coins()).keys()
@@ -89,8 +97,10 @@ async def main():
         cl = ExClient(gt, b)
         await cl.set_pairs()
         pms = await cl.set_coins()
-        pms = await cl.set_curs()
+        pms = await cl.cur_pms_map()
         pms = await cl.set_pms()
+        pms = await cl.set_coins()
+        pms = await cl.set_curs()
         _ads = await cl.ads("USDT", "RUB", True, ["payeer"], 1000)
         # curs = await cl.curs()
         # await cl.coins()
